# mypy-boto3-stepfunctions

[![PyPI - mypy-boto3-stepfunctions](https://img.shields.io/pypi/v/mypy-boto3-stepfunctions.svg?color=blue)](https://pypi.org/project/mypy-boto3-stepfunctions)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-stepfunctions.svg?color=blue)](https://pypi.org/project/mypy-boto3-stepfunctions)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.SFN 1.16.44](https://boto3.amazonaws.com/v1/documentation/api/1.16.44/reference/services/stepfunctions.html#SFN) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.3.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-stepfunctions](#mypy-boto3-stepfunctions)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `SFN` service.

```bash
python -m pip install boto3-stubs[stepfunctions]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[stepfunctions]` in your environment: `python -m pip install 'boto3-stubs[stepfunctions]'`

Both type checking and auto-complete should work for `SFN` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[stepfunctions]` in your environment: `python -m pip install 'boto3-stubs[stepfunctions]'`

Both type checking and auto-complete should work for `SFN` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[stepfunctions]` in your environment: `python -m pip install 'boto3-stubs[stepfunctions]'`
- Run `mypy` as usual

Type checking should work for `SFN` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[stepfunctions]` in your environment: `python -m pip install 'boto3-stubs[stepfunctions]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `SFN` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`SFNClient` provides annotations for `boto3.client("stepfunctions")`.

```python
import boto3

from mypy_boto3_stepfunctions import SFNClient

client: SFNClient = boto3.client("stepfunctions")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: SFNClient = session.client("stepfunctions")
```

### Paginators annotations

`mypy_boto3_stepfunctions.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_stepfunctions import SFNClient
from mypy_boto3_stepfunctions.paginator import (
    GetExecutionHistoryPaginator,
    ListActivitiesPaginator,
    ListExecutionsPaginator,
    ListStateMachinesPaginator,
)

client: SFNClient = boto3.client("stepfunctions")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
get_execution_history_paginator: GetExecutionHistoryPaginator = client.get_paginator("get_execution_history")
list_activities_paginator: ListActivitiesPaginator = client.get_paginator("list_activities")
list_executions_paginator: ListExecutionsPaginator = client.get_paginator("list_executions")
list_state_machines_paginator: ListStateMachinesPaginator = client.get_paginator("list_state_machines")
```







### Typed dictionations

`mypy_boto3_stepfunctions.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_stepfunctions.type_defs import (
    ActivityFailedEventDetailsTypeDef,
    ActivityListItemTypeDef,
    ActivityScheduledEventDetailsTypeDef,
    ActivityScheduleFailedEventDetailsTypeDef,
    ActivityStartedEventDetailsTypeDef,
    ActivitySucceededEventDetailsTypeDef,
    ActivityTimedOutEventDetailsTypeDef,
    BillingDetailsTypeDef,
    CloudWatchEventsExecutionDataDetailsTypeDef,
    CloudWatchLogsLogGroupTypeDef,
    CreateActivityOutputTypeDef,
    CreateStateMachineOutputTypeDef,
    DescribeActivityOutputTypeDef,
    DescribeExecutionOutputTypeDef,
    DescribeStateMachineForExecutionOutputTypeDef,
    DescribeStateMachineOutputTypeDef,
    ExecutionAbortedEventDetailsTypeDef,
    ExecutionFailedEventDetailsTypeDef,
    ExecutionListItemTypeDef,
    ExecutionStartedEventDetailsTypeDef,
    ExecutionSucceededEventDetailsTypeDef,
    ExecutionTimedOutEventDetailsTypeDef,
    GetActivityTaskOutputTypeDef,
    GetExecutionHistoryOutputTypeDef,
    HistoryEventExecutionDataDetailsTypeDef,
    HistoryEventTypeDef,
    LambdaFunctionFailedEventDetailsTypeDef,
    LambdaFunctionScheduledEventDetailsTypeDef,
    LambdaFunctionScheduleFailedEventDetailsTypeDef,
    LambdaFunctionStartFailedEventDetailsTypeDef,
    LambdaFunctionSucceededEventDetailsTypeDef,
    LambdaFunctionTimedOutEventDetailsTypeDef,
    ListActivitiesOutputTypeDef,
    ListExecutionsOutputTypeDef,
    ListStateMachinesOutputTypeDef,
    ListTagsForResourceOutputTypeDef,
    LogDestinationTypeDef,
    LoggingConfigurationTypeDef,
    MapIterationEventDetailsTypeDef,
    MapStateStartedEventDetailsTypeDef,
    PaginatorConfigTypeDef,
    ResponseMetadata,
    StartExecutionOutputTypeDef,
    StartSyncExecutionOutputTypeDef,
    StateEnteredEventDetailsTypeDef,
    StateExitedEventDetailsTypeDef,
    StateMachineListItemTypeDef,
    StopExecutionOutputTypeDef,
    TagTypeDef,
    TaskFailedEventDetailsTypeDef,
    TaskScheduledEventDetailsTypeDef,
    TaskStartedEventDetailsTypeDef,
    TaskStartFailedEventDetailsTypeDef,
    TaskSubmitFailedEventDetailsTypeDef,
    TaskSubmittedEventDetailsTypeDef,
    TaskSucceededEventDetailsTypeDef,
    TaskTimedOutEventDetailsTypeDef,
    TracingConfigurationTypeDef,
    UpdateStateMachineOutputTypeDef,
)

def get_structure() -> ActivityFailedEventDetailsTypeDef:
    return {
      ...
    }
```
